{% if not vars.draft_parent_record.skip %}
from invenio_records.systemfields import ConstantField
{{ vars.draft_parent_record.imports|generate_import }}
{{ vars.draft_parent_record_metadata.class|generate_import }}

class {{ vars.draft_parent_record|class_header }}:

    model_cls = {{ vars.draft_parent_record_metadata.class|base_name }}

    #schema = ConstantField(
    #    "$schema", "{{ settings.schema_server }}{{ vars.draft_parent_record_schema.name }}"
    #)
{% endif %}