{% if not vars.draft_parent_record_metadata.skip %}
{{ vars.draft_parent_record_metadata.imports|generate_import }}


class {{ vars.draft_parent_record_metadata|class_header }}:

    __tablename__ = "{{ vars.draft_parent_record_metadata.table }}"
{% endif %}