{% if not vars.draft_parent_record.skip %}
class {{ record_metadata|class_header }}:
    {% if not vars.draft_parent_record_metadata.skip %}
    __parent_record_model__ = {{ vars.draft_parent_record_metadata.class|base_name }}
    {% endif %}
{% endif %}